==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/inputs/HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.inputs

import com.pulumi.azurenative.datareplication.inputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * HyperV to AzStackHCI Replication extension model custom properties.
 * @property azStackHciFabricArmId Gets or sets the ARM Id of the target AzStackHCI fabric.
 * @property hyperVFabricArmId Gets or sets the ARM Id of the source HyperV fabric.
 * @property instanceType Gets or sets the instance type.
 * Expected value is 'HyperVToAzStackHCI'.
 * @property storageAccountId Gets or sets the storage account Id.
 * @property storageAccountSasSecretName Gets or sets the Sas Secret of storage account.
 */
public data class HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs(
    public val azStackHciFabricArmId: Output<String>,
    public val hyperVFabricArmId: Output<String>,
    public val instanceType: Output<String>,
    public val storageAccountId: Output<String>? = null,
    public val storageAccountSasSecretName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.datareplication.inputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datareplication.inputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs =
        com.pulumi.azurenative.datareplication.inputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.builder()
            .azStackHciFabricArmId(azStackHciFabricArmId.applyValue({ args0 -> args0 }))
            .hyperVFabricArmId(hyperVFabricArmId.applyValue({ args0 -> args0 }))
            .instanceType(instanceType.applyValue({ args0 -> args0 }))
            .storageAccountId(storageAccountId?.applyValue({ args0 -> args0 }))
            .storageAccountSasSecretName(storageAccountSasSecretName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs].
 */
@PulumiTagMarker
public class HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgsBuilder internal
constructor() {
    private var azStackHciFabricArmId: Output<String>? = null

    private var hyperVFabricArmId: Output<String>? = null

    private var instanceType: Output<String>? = null

    private var storageAccountId: Output<String>? = null

    private var storageAccountSasSecretName: Output<String>? = null

    /**
     * @param value Gets or sets the ARM Id of the target AzStackHCI fabric.
     */
    @JvmName("scxmwiyecsraijtk")
    public suspend fun azStackHciFabricArmId(`value`: Output<String>) {
        this.azStackHciFabricArmId = value
    }

    /**
     * @param value Gets or sets the ARM Id of the source HyperV fabric.
     */
    @JvmName("ehkberhjjfdiskmt")
    public suspend fun hyperVFabricArmId(`value`: Output<String>) {
        this.hyperVFabricArmId = value
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'HyperVToAzStackHCI'.
     */
    @JvmName("mdkgflclavxevhmb")
    public suspend fun instanceType(`value`: Output<String>) {
        this.instanceType = value
    }

    /**
     * @param value Gets or sets the storage account Id.
     */
    @JvmName("tdbittoktpskeggy")
    public suspend fun storageAccountId(`value`: Output<String>) {
        this.storageAccountId = value
    }

    /**
     * @param value Gets or sets the Sas Secret of storage account.
     */
    @JvmName("reupatdgeqaklmjt")
    public suspend fun storageAccountSasSecretName(`value`: Output<String>) {
        this.storageAccountSasSecretName = value
    }

    /**
     * @param value Gets or sets the ARM Id of the target AzStackHCI fabric.
     */
    @JvmName("lsvingcyietwdyny")
    public suspend fun azStackHciFabricArmId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azStackHciFabricArmId = mapped
    }

    /**
     * @param value Gets or sets the ARM Id of the source HyperV fabric.
     */
    @JvmName("bxkfdwqntemvelqy")
    public suspend fun hyperVFabricArmId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hyperVFabricArmId = mapped
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'HyperVToAzStackHCI'.
     */
    @JvmName("uljcnvqvrwwhietg")
    public suspend fun instanceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.instanceType = mapped
    }

    /**
     * @param value Gets or sets the storage account Id.
     */
    @JvmName("wfchqwxuupqjldnp")
    public suspend fun storageAccountId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountId = mapped
    }

    /**
     * @param value Gets or sets the Sas Secret of storage account.
     */
    @JvmName("ksjtfxkbmjtjrdty")
    public suspend fun storageAccountSasSecretName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountSasSecretName = mapped
    }

    internal fun build(): HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs =
        HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs(
            azStackHciFabricArmId = azStackHciFabricArmId ?: throw
                PulumiNullFieldException("azStackHciFabricArmId"),
            hyperVFabricArmId = hyperVFabricArmId ?: throw PulumiNullFieldException("hyperVFabricArmId"),
            instanceType = instanceType ?: throw PulumiNullFieldException("instanceType"),
            storageAccountId = storageAccountId,
            storageAccountSasSecretName = storageAccountSasSecretName,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datareplication/kotlin/inputs/HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datareplication.kotlin.inputs

import com.pulumi.azurenative.datareplication.inputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * HyperV to AzStackHCI Replication extension model custom properties.
 * @property azStackHciFabricArmId Gets or sets the ARM Id of the target AzStackHCI fabric.
 * @property hyperVFabricArmId Gets or sets the ARM Id of the source HyperV fabric.
 * @property instanceType Gets or sets the instance type.
 * Expected value is 'HyperVToAzStackHCI'.
 * @property storageAccountId Gets or sets the storage account Id.
 * @property storageAccountSasSecretName Gets or sets the Sas Secret of storage account.
 */
public data class HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs(
    public val azStackHciFabricArmId: Output<String>,
    public val hyperVFabricArmId: Output<String>,
    public val instanceType: Output<String>,
    public val storageAccountId: Output<String>? = null,
    public val storageAccountSasSecretName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.datareplication.inputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.datareplication.inputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs =
        com.pulumi.azurenative.datareplication.inputs.HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs.builder()
            .azStackHciFabricArmId(azStackHciFabricArmId.applyValue({ args0 -> args0 }))
            .hyperVFabricArmId(hyperVFabricArmId.applyValue({ args0 -> args0 }))
            .instanceType(instanceType.applyValue({ args0 -> args0 }))
            .storageAccountId(storageAccountId?.applyValue({ args0 -> args0 }))
            .storageAccountSasSecretName(storageAccountSasSecretName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs].
 */
@PulumiTagMarker
public class HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgsBuilder internal
constructor() {
    private var azStackHciFabricArmId: Output<String>? = null

    private var hyperVFabricArmId: Output<String>? = null

    private var instanceType: Output<String>? = null

    private var storageAccountId: Output<String>? = null

    private var storageAccountSasSecretName: Output<String>? = null

    /**
     * @param value Gets or sets the ARM Id of the target AzStackHCI fabric.
     */
    @JvmName("kryppsnsuihcesxv")
    public suspend fun azStackHciFabricArmId(`value`: Output<String>) {
        this.azStackHciFabricArmId = value
    }

    /**
     * @param value Gets or sets the ARM Id of the source HyperV fabric.
     */
    @JvmName("kebantpepqfgbota")
    public suspend fun hyperVFabricArmId(`value`: Output<String>) {
        this.hyperVFabricArmId = value
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'HyperVToAzStackHCI'.
     */
    @JvmName("wpheqwiahmjuiqpu")
    public suspend fun instanceType(`value`: Output<String>) {
        this.instanceType = value
    }

    /**
     * @param value Gets or sets the storage account Id.
     */
    @JvmName("yhmrlaetvxxhkygi")
    public suspend fun storageAccountId(`value`: Output<String>) {
        this.storageAccountId = value
    }

    /**
     * @param value Gets or sets the Sas Secret of storage account.
     */
    @JvmName("ssyyewvtdcgoroyj")
    public suspend fun storageAccountSasSecretName(`value`: Output<String>) {
        this.storageAccountSasSecretName = value
    }

    /**
     * @param value Gets or sets the ARM Id of the target AzStackHCI fabric.
     */
    @JvmName("jkptojpofhtqjonj")
    public suspend fun azStackHciFabricArmId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.azStackHciFabricArmId = mapped
    }

    /**
     * @param value Gets or sets the ARM Id of the source HyperV fabric.
     */
    @JvmName("arqfsmkxykeuqpgo")
    public suspend fun hyperVFabricArmId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hyperVFabricArmId = mapped
    }

    /**
     * @param value Gets or sets the instance type.
     * Expected value is 'HyperVToAzStackHCI'.
     */
    @JvmName("opqiddbxaadqekel")
    public suspend fun instanceType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.instanceType = mapped
    }

    /**
     * @param value Gets or sets the storage account Id.
     */
    @JvmName("ivjnmmsivontbdrd")
    public suspend fun storageAccountId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountId = mapped
    }

    /**
     * @param value Gets or sets the Sas Secret of storage account.
     */
    @JvmName("batnjrlavxkmpula")
    public suspend fun storageAccountSasSecretName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.storageAccountSasSecretName = mapped
    }

    internal fun build(): HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs =
        HyperVToAzStackHCIReplicationExtensionModelCustomPropertiesArgs(
            azStackHciFabricArmId = azStackHciFabricArmId ?: throw
                PulumiNullFieldException("azStackHciFabricArmId"),
            hyperVFabricArmId = hyperVFabricArmId ?: throw PulumiNullFieldException("hyperVFabricArmId"),
            instanceType = instanceType ?: throw PulumiNullFieldException("instanceType"),
            storageAccountId = storageAccountId,
            storageAccountSasSecretName = storageAccountSasSecretName,
        )
}
